
#==============================================================================#
# $Id: config.rb,v 1.13 2003/11/17 19:33:12 yuya Exp $
#==============================================================================#

require 'rbconfig'

#==============================================================================#

module Exerb

  CORE_PATH   = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
  CORE_NAME   = {'cui' => 'ruby181c.exc', 'cuirt' => 'ruby181crt.exc', 'gui' => 'ruby181g.exc', 'guirt' => 'ruby181grt.exc'}
  PLUGIN_PATH = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
  PLUGIN_NAME = {'zlib' => 'mod_zlib.exm', 'bruby' => 'mod_bruby.exm'}

  if $Exerb
    selfpath = File.dirname(Exerb.filepath)
    CORE_PATH   << selfpath
    PLUGIN_PATH << selfpath
  end

end # Exerb

#==============================================================================#

configcc = File.join(File.dirname(__FILE__), 'configcc.rb')
if File.exist?(configcc)
  require(configcc)
end

#==============================================================================#
#==============================================================================#
